@@ -1,14 +1,14 @@
-use std::{cell::RefCell, rc::Rc};
+use std::sync::{Arc, Mutex};
 
-pub type OptionCache<T> = RefCell<Option<Rc<T>>>;
+pub type OptionCache<T> = Mutex<Option<Arc<T>>>;
 
 pub trait OptionCacheExt<T> {
-	fn try_get_or_insert<E>(&self, build: impl FnOnce() -> Result<T, E>) -> Result<Rc<T>, E>;
+	fn try_get_or_insert<E>(&self, build: impl FnOnce() -> Result<T, E>) -> Result<Arc<T>, E>;
 }
 
 impl<T> OptionCacheExt<T> for OptionCache<T> {
-	fn try_get_or_insert<E>(&self, build: impl FnOnce() -> Result<T, E>) -> Result<Rc<T>, E> {
-		Ok(match &mut *self.borrow_mut() {
+	fn try_get_or_insert<E>(&self, build: impl FnOnce() -> Result<T, E>) -> Result<Arc<T>, E> {
+		Ok(match &mut *self.lock().unwrap() {
 			Some(inner) => inner.clone(),
 			option @ None => option.insert(build()?.into()).clone(),
 		})
@@ -24,7 +24,7 @@ mod test {
 	#[test]
 	fn default() {
 		let cache: OptionCache<u8> = Default::default();
-		assert_eq!(cache.into_inner(), None)
+		assert_eq!(cache.into_inner().unwrap(), None)
 	}
 
 	#[test]
